@@ -71,8 +71,7 @@ reprex_document <- function(venue = c("gh", "r", "rtf", "html", "slack", "so", "
     opts_chunk[["tidy"]] <- "styler"
   }
   opts_knit <- list(
-    upload.fun = switch(
-      venue,
+    upload.fun = switch(venue,
       r = identity,
       knitr::imgur_upload
     )
@@ -129,14 +128,13 @@ reprex_document <- function(venue = c("gh", "r", "rtf", "html", "slack", "so", "
   format
 }
 
+# should be kept in sync with the options (re)stored in reprex_render_impl() in
+# the prex() case (new_session = FALSE)
 reprex_opts <- function(venue = "gh") {
-  string <- glue::glue('
+  string <- glue('
     ```{{r reprex-options, include = FALSE}}
     options(
       keep.source = TRUE,
-      rlang_trace_top_env = globalenv(),
-      `rlang:::force_unhandled_error` = TRUE,
-      rlang_backtrace_on_error = "full",
       crayon.enabled = FALSE,
       reprex.current_venue = "{venue}"
     )
@@ -153,21 +151,24 @@ rprofile_alert <- function(venue = "gh") {
     "include = file.exists('.Rprofile'), eval = file.exists('.Rprofile')"
 
   c(
-    glue::glue("```{{r, results = 'asis', echo = FALSE, {include_eval}}}"),
-    glue::glue('cat(sprintf({fmt}, normalizePath(".Rprofile")))'),
+    glue("```{{r, results = 'asis', echo = FALSE, {include_eval}}}"),
+    glue('cat(sprintf({fmt}, normalizePath(".Rprofile")))'),
     "```"
   )
 }
 
 ad <- function(venue = "gh") {
+  markdown_ad <- glue('
+    Created on `r Sys.Date()` with \\
+    [reprex v`r utils::packageVersion("reprex")`]\\
+    (https://reprex.tidyverse.org)')
   if (venue %in% c("gh", "html")) {
-    glue::glue('
-      <sup>Created on `r Sys.Date()` by the \\
-      [reprex package](https://reprex.tidyverse.org) \\
-      (v`r utils::packageVersion("reprex")`)</sup>')
-  } else { # venue %in% c("r", "rtf", "slack")
-    glue::glue('
-      Created on `r Sys.Date()` by the reprex package \\
+    glue('<sup>{markdown_ad}</sup>')
+  } else if (venue == "slack") {
+    markdown_ad
+  } else { # venue %in% c("r", "rtf")
+    glue('
+      Created on `r Sys.Date()` with reprex \\
       v`r utils::packageVersion("reprex")` https://reprex.tidyverse.org')
   }
 }
